##  2. Data Controller
Data Controller in terms of the SAP LeanIX software is, if you are not an employee or a contractor of SAP LeanIX, the Customer of SAP LeanIX you are employed with or contracted by.
If you have difficulties in finding out who your Data Controller is and, respectively, its Data Protection Officer, please refer to
If you are not employed or contracted by any customer of SAP LeanIX, the Data Controller is:
LeanIX GmbH, Friedrich-Ebert-Allee 37-39, 53113 Bonn, Germany
Contact email:
Data Protection Officer of LeanIX is Andreas Schmidt, c/o postal address above (refer to Data Protection Officer, personally)
